@@ -198,6 +198,18 @@ def sortB(a, b, reverse=False):
     else:
         return a2, b2
 
+def sortBs(a_list, b, reverse=False):
+    # sort A_list with B
+    n = len(a_list)
+    new_a_list = []
+    for i, a in enumerate(a_list):
+        if i == n - 1: 
+            new_a, new_b = sortB(a, b, reverse=reverse)
+        else: 
+            new_a, _ = sortB(a, b, reverse=reverse)
+        new_a_list.append(new_a)
+    return new_a_list, new_b
+        
 def unilist(a):
     return list(set(a))
 
