@@ -20,6 +20,8 @@ import shutil
 from shutil import copy2
 import ruamel.yaml as yaml
 import numpy as np
+import pathlib
+
 
 def make_parent_dir(filename):
     parent_dir = os.path.dirname(filename)
@@ -35,7 +37,30 @@ def is_empty(path):
     return not os.path.exists(path) or (os.path.isdir(path) and len(os.listdir(path)) == 0)
 
 
+def txt_like(filename):
+    equivalent_suffix = [
+        '.txt',
+        '.md',
+        '.sh',
+        '.bash',
+        '.log',
+        '.tex',
+        '.py',
+        '.bash_profile',
+        '.bashrc',
+        '.out'
+    ]
+        
+    return any(filename.endswith(suffix) for suffix in equivalent_suffix)
+
+
+def try_pathlib2str(path):
+    if isinstance(path, pathlib.Path):
+        return str(path)
+    return path
+
 def load(filename):
+    filename = try_pathlib2str(filename)
     # adding the symbolic link reading
     if os.path.islink(filename): 
         filename = os.readlink(filename)
@@ -48,7 +73,7 @@ def load(filename):
     elif filename.endswith('.yml') or filename.endswith('.yaml'): 
         with open(filename, 'r') as f:
             loaded = yaml.safe_load(f)
-    elif filename.endswith('.txt') or filename.endswith('.md') or filename.endswith('.sh') or filename.endswith('.bash') or filename.endswith('.log'): 
+    elif txt_like(filename): 
         with open(filename, 'r') as f:
             loaded = f.read()
     else:
@@ -64,11 +89,12 @@ class NumpyEncoder(json.JSONEncoder):
 
 def dump(content, filename):
     # robust argument
-    if isinstance(content, str) and not isinstance(filename, str):
+    if (isinstance(content, str) or isinstance(content, pathlib.Path)) and (not isinstance(filename, str) and not isinstance(filename, pathlib.Path)):
         # BEAWARE: str might be insufficient
         # swap 
         content, filename = filename, content
 
+    filename = try_pathlib2str(filename)
     if filename.endswith('.pkl'):
         with open(filename, 'wb') as f:
             pickle.dump(content, f, protocol=pickle.HIGHEST_PROTOCOL)
@@ -78,7 +104,7 @@ def dump(content, filename):
     elif filename.endswith('.yml') or filename.endswith('.yaml'): 
         with open(filename, 'w') as f:
             yaml.safe_dump(content, f, default_flow_style=False)
-    elif filename.endswith('.txt') or filename.endswith('.md') or filename.endswith('.sh') or filename.endswith('.bash') or filename.endswith('.log'): 
+    elif txt_like(filename): 
         with open(filename, 'w') as f:
             f.write(content)
     else:
@@ -115,3 +141,7 @@ def copy_verbose(src, dst, logger=None):
 
 def copytree_verbose(src, dst, logger=None):
     shutil.copytree(src, dst, copy_function=copy_verbose)
+
+def get_lastline(file_str):
+    return file_str.strip().split('\n')[-1]
+    
\ No newline at end of file
